# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMESecretContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"value": "DCMESecretValueContract", "expires_on": "datetime", "parameters": "dict(str, object)"}

    attribute_map = {"value": "value", "expires_on": "expiresOn", "parameters": "parameters"}

    def __init__(self, value=None, expires_on=None, parameters=None, _configuration=None):  # noqa: E501
        """DCMESecretContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._value = None
        self._expires_on = None
        self._parameters = None
        self.discriminator = None

        if value is not None:
            self.value = value
        if expires_on is not None:
            self.expires_on = expires_on
        self.parameters = parameters

    @property
    def value(self):
        """Gets the value of this DCMESecretContract.  # noqa: E501


        :return: The value of this DCMESecretContract.  # noqa: E501
        :rtype: DCMESecretValueContract
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this DCMESecretContract.


        :param value: The value of this DCMESecretContract.  # noqa: E501
        :type: DCMESecretValueContract
        """

        self._value = value

    @property
    def expires_on(self):
        """Gets the expires_on of this DCMESecretContract.  # noqa: E501


        :return: The expires_on of this DCMESecretContract.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_on

    @expires_on.setter
    def expires_on(self, expires_on):
        """Sets the expires_on of this DCMESecretContract.


        :param expires_on: The expires_on of this DCMESecretContract.  # noqa: E501
        :type: datetime
        """

        self._expires_on = expires_on

    @property
    def parameters(self):
        """Gets the parameters of this DCMESecretContract.  # noqa: E501


        :return: The parameters of this DCMESecretContract.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this DCMESecretContract.


        :param parameters: The parameters of this DCMESecretContract.  # noqa: E501
        :type: dict(str, object)
        """
        if self._configuration.client_side_validation and parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMESecretContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMESecretContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMESecretContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class DCMEAdminApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def d_cme_admin_delete_connection_admin(self, object_id, **kwargs):  # noqa: E501
        """Delete a DCM Connection  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_delete_connection_admin(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: DCMEDeleteConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_delete_connection_admin_with_http_info(object_id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_delete_connection_admin_with_http_info(object_id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_delete_connection_admin_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Delete a DCM Connection  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_delete_connection_admin_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: DCMEDeleteConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["object_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method d_cme_admin_delete_connection_admin" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and ("object_id" not in params or params["object_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `object_id` when calling `d_cme_admin_delete_connection_admin`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in params:
            path_params["objectId"] = params["object_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections/{objectId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DCMEDeleteConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_delete_dcme_connection_handling_rule(self, id, **kwargs):  # noqa: E501
        """Deletes an existing DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_delete_dcme_connection_handling_rule(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The DCME ConnectionHandlingRule to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_delete_dcme_connection_handling_rule_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_delete_dcme_connection_handling_rule_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_delete_dcme_connection_handling_rule_with_http_info(self, id, **kwargs):  # noqa: E501
        """Deletes an existing DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_delete_dcme_connection_handling_rule_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The DCME ConnectionHandlingRule to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_delete_dcme_connection_handling_rule" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `id` when calling `d_cme_admin_delete_dcme_connection_handling_rule`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connectionhandlingrules/{id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_get_all_connections_admin(self, **kwargs):  # noqa: E501
        """Retrieve a list of DCM Connection records  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_all_connections_admin(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_id: Filters Connections by it's Connection Id
        :param str visible_by: If present, returns same result as for the user
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_get_all_connections_admin_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_get_all_connections_admin_with_http_info(**kwargs)  # noqa: E501
            return data

    def d_cme_admin_get_all_connections_admin_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a list of DCM Connection records  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_all_connections_admin_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_id: Filters Connections by it's Connection Id
        :param str visible_by: If present, returns same result as for the user
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["connection_id", "visible_by"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method d_cme_admin_get_all_connections_admin" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "connection_id" in params:
            query_params.append(("connectionId", params["connection_id"]))  # noqa: E501
        if "visible_by" in params:
            query_params.append(("visibleBy", params["visible_by"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DCMEGetConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_get_all_dcme_connection_handling_rules(self, **kwargs):  # noqa: E501
        """Returns all DCME ConnectionHandlingRules  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_all_dcme_connection_handling_rules(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_get_all_dcme_connection_handling_rules_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_get_all_dcme_connection_handling_rules_with_http_info(**kwargs)  # noqa: E501
            return data

    def d_cme_admin_get_all_dcme_connection_handling_rules_with_http_info(self, **kwargs):  # noqa: E501
        """Returns all DCME ConnectionHandlingRules  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_all_dcme_connection_handling_rules_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_get_all_dcme_connection_handling_rules" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connectionhandlingrules",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_get_connection_admin(self, object_id, **kwargs):  # noqa: E501
        """Retrieve a DCM Connection record  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_connection_admin(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_get_connection_admin_with_http_info(object_id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_get_connection_admin_with_http_info(object_id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_get_connection_admin_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Retrieve a DCM Connection record  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_connection_admin_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["object_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method d_cme_admin_get_connection_admin" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and ("object_id" not in params or params["object_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `object_id` when calling `d_cme_admin_get_connection_admin`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in params:
            path_params["objectId"] = params["object_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections/{objectId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DCMEGetConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_get_dcme_connection_handling_rule(self, id, **kwargs):  # noqa: E501
        """Gets a DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_dcme_connection_handling_rule(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The ID of the DCME ConnectionHandlingRule to return (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_get_dcme_connection_handling_rule_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_get_dcme_connection_handling_rule_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_get_dcme_connection_handling_rule_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_get_dcme_connection_handling_rule_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: The ID of the DCME ConnectionHandlingRule to return (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_get_dcme_connection_handling_rule" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `id` when calling `d_cme_admin_get_dcme_connection_handling_rule`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connectionhandlingrules/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_unshare_connection_for_collaboration_admin(self, object_id, **kwargs):  # noqa: E501
        """Unshares a DCM Connection shared for collaboration  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_unshare_connection_for_collaboration_admin(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_unshare_connection_for_collaboration_admin_with_http_info(object_id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_unshare_connection_for_collaboration_admin_with_http_info(object_id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_unshare_connection_for_collaboration_admin_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Unshares a DCM Connection shared for collaboration  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_unshare_connection_for_collaboration_admin_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["object_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_unshare_connection_for_collaboration_admin" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and ("object_id" not in params or params["object_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `object_id` when calling `d_cme_admin_unshare_connection_for_collaboration_admin`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in params:
            path_params["objectId"] = params["object_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections/{objectId}/sharing/collaboration",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_unshare_connection_for_execution_admin(self, object_id, **kwargs):  # noqa: E501
        """Unshares a DCM Connection shared for execution  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_unshare_connection_for_execution_admin(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_unshare_connection_for_execution_admin_with_http_info(object_id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_unshare_connection_for_execution_admin_with_http_info(object_id, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_unshare_connection_for_execution_admin_with_http_info(self, object_id, **kwargs):  # noqa: E501
        """Unshares a DCM Connection shared for execution  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_unshare_connection_for_execution_admin_with_http_info(object_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str object_id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["object_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_unshare_connection_for_execution_admin" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'object_id' is set
        if self.api_client.client_side_validation and ("object_id" not in params or params["object_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `object_id` when calling `d_cme_admin_unshare_connection_for_execution_admin`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_id" in params:
            path_params["objectId"] = params["object_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections/{objectId}/sharing/execution",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_upsert_dcm_connection(self, upsert_connection_contract, **kwargs):  # noqa: E501
        """Create or update a DCM Connection on behalf of user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_upsert_dcm_connection(upsert_connection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DCMEUpsertConnectionAdminContract upsert_connection_contract:  (required)
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_upsert_dcm_connection_with_http_info(upsert_connection_contract, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_upsert_dcm_connection_with_http_info(upsert_connection_contract, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_upsert_dcm_connection_with_http_info(self, upsert_connection_contract, **kwargs):  # noqa: E501
        """Create or update a DCM Connection on behalf of user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_upsert_dcm_connection_with_http_info(upsert_connection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DCMEUpsertConnectionAdminContract upsert_connection_contract:  (required)
        :return: DCMEGetConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["upsert_connection_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method d_cme_admin_upsert_dcm_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'upsert_connection_contract' is set
        if self.api_client.client_side_validation and (
            "upsert_connection_contract" not in params or params["upsert_connection_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `upsert_connection_contract` when calling `d_cme_admin_upsert_dcm_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "upsert_connection_contract" in params:
            body_params = params["upsert_connection_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connections",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DCMEGetConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def d_cme_admin_upsert_dcme_connection_handling_rule(self, rule, **kwargs):  # noqa: E501
        """Adds (when id is null) or updates (when id is defined) a new DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_upsert_dcme_connection_handling_rule(rule, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DCMEConnectionHandlingRuleContract rule: The DCME ConnectionHandlingRule to create or update (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_admin_upsert_dcme_connection_handling_rule_with_http_info(rule, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_admin_upsert_dcme_connection_handling_rule_with_http_info(rule, **kwargs)  # noqa: E501
            return data

    def d_cme_admin_upsert_dcme_connection_handling_rule_with_http_info(self, rule, **kwargs):  # noqa: E501
        """Adds (when id is null) or updates (when id is defined) a new DCM.E ConnectionHandlingRule  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_admin_upsert_dcme_connection_handling_rule_with_http_info(rule, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param DCMEConnectionHandlingRuleContract rule: The DCME ConnectionHandlingRule to create or update (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["rule"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_admin_upsert_dcme_connection_handling_rule" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'rule' is set
        if self.api_client.client_side_validation and ("rule" not in params or params["rule"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `rule` when calling `d_cme_admin_upsert_dcme_connection_handling_rule`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "rule" in params:
            body_params = params["rule"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/dcm/admin/connectionhandlingrules",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEUserView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"id": "str", "email": "str"}

    attribute_map = {"id": "id", "email": "email"}

    def __init__(self, id=None, email=None, _configuration=None):  # noqa: E501
        """DCMEUserView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._email = None
        self.discriminator = None

        self.id = id
        self.email = email

    @property
    def id(self):
        """Gets the id of this DCMEUserView.  # noqa: E501


        :return: The id of this DCMEUserView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DCMEUserView.


        :param id: The id of this DCMEUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def email(self):
        """Gets the email of this DCMEUserView.  # noqa: E501


        :return: The email of this DCMEUserView.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DCMEUserView.


        :param email: The email of this DCMEUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEUserView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEUserView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEUserView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class SubscriptionUserWorkflowCountView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "user_count": "int",
        "workflow_count": "int",
        "id": "str",
        "name": "str",
        "credential_id": "str",
        "can_share_schedules": "bool",
    }

    attribute_map = {
        "user_count": "userCount",
        "workflow_count": "workflowCount",
        "id": "id",
        "name": "name",
        "credential_id": "credentialId",
        "can_share_schedules": "canShareSchedules",
    }

    def __init__(
        self,
        user_count=None,
        workflow_count=None,
        id=None,
        name=None,
        credential_id=None,
        can_share_schedules=None,
        _configuration=None,
    ):  # noqa: E501
        """SubscriptionUserWorkflowCountView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._user_count = None
        self._workflow_count = None
        self._id = None
        self._name = None
        self._credential_id = None
        self._can_share_schedules = None
        self.discriminator = None

        self.user_count = user_count
        self.workflow_count = workflow_count
        self.id = id
        self.name = name
        self.credential_id = credential_id
        self.can_share_schedules = can_share_schedules

    @property
    def user_count(self):
        """Gets the user_count of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The user_count of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this SubscriptionUserWorkflowCountView.


        :param user_count: The user_count of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and user_count is None:
            raise ValueError("Invalid value for `user_count`, must not be `None`")  # noqa: E501

        self._user_count = user_count

    @property
    def workflow_count(self):
        """Gets the workflow_count of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The workflow_count of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: int
        """
        return self._workflow_count

    @workflow_count.setter
    def workflow_count(self, workflow_count):
        """Sets the workflow_count of this SubscriptionUserWorkflowCountView.


        :param workflow_count: The workflow_count of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and workflow_count is None:
            raise ValueError("Invalid value for `workflow_count`, must not be `None`")  # noqa: E501

        self._workflow_count = workflow_count

    @property
    def id(self):
        """Gets the id of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The id of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionUserWorkflowCountView.


        :param id: The id of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The name of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionUserWorkflowCountView.


        :param name: The name of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def credential_id(self):
        """Gets the credential_id of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The credential_id of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: str
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this SubscriptionUserWorkflowCountView.


        :param credential_id: The credential_id of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and credential_id is None:
            raise ValueError("Invalid value for `credential_id`, must not be `None`")  # noqa: E501

        self._credential_id = credential_id

    @property
    def can_share_schedules(self):
        """Gets the can_share_schedules of this SubscriptionUserWorkflowCountView.  # noqa: E501


        :return: The can_share_schedules of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_schedules

    @can_share_schedules.setter
    def can_share_schedules(self, can_share_schedules):
        """Sets the can_share_schedules of this SubscriptionUserWorkflowCountView.


        :param can_share_schedules: The can_share_schedules of this SubscriptionUserWorkflowCountView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and can_share_schedules is None:
            raise ValueError("Invalid value for `can_share_schedules`, must not be `None`")  # noqa: E501

        self._can_share_schedules = can_share_schedules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SubscriptionUserWorkflowCountView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionUserWorkflowCountView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubscriptionUserWorkflowCountView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMESharingForCollaborationView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "borrowed_credentials": "list[str]",
        "shared_credentials": "list[str]",
        "users": "list[DCMEUserView]",
        "user_groups": "list[DCMEUserGroupView]",
    }

    attribute_map = {
        "borrowed_credentials": "borrowedCredentials",
        "shared_credentials": "sharedCredentials",
        "users": "users",
        "user_groups": "userGroups",
    }

    def __init__(
        self, borrowed_credentials=None, shared_credentials=None, users=None, user_groups=None, _configuration=None
    ):  # noqa: E501
        """DCMESharingForCollaborationView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._borrowed_credentials = None
        self._shared_credentials = None
        self._users = None
        self._user_groups = None
        self.discriminator = None

        self.borrowed_credentials = borrowed_credentials
        self.shared_credentials = shared_credentials
        self.users = users
        self.user_groups = user_groups

    @property
    def borrowed_credentials(self):
        """Gets the borrowed_credentials of this DCMESharingForCollaborationView.  # noqa: E501


        :return: The borrowed_credentials of this DCMESharingForCollaborationView.  # noqa: E501
        :rtype: list[str]
        """
        return self._borrowed_credentials

    @borrowed_credentials.setter
    def borrowed_credentials(self, borrowed_credentials):
        """Sets the borrowed_credentials of this DCMESharingForCollaborationView.


        :param borrowed_credentials: The borrowed_credentials of this DCMESharingForCollaborationView.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and borrowed_credentials is None:
            raise ValueError("Invalid value for `borrowed_credentials`, must not be `None`")  # noqa: E501

        self._borrowed_credentials = borrowed_credentials

    @property
    def shared_credentials(self):
        """Gets the shared_credentials of this DCMESharingForCollaborationView.  # noqa: E501


        :return: The shared_credentials of this DCMESharingForCollaborationView.  # noqa: E501
        :rtype: list[str]
        """
        return self._shared_credentials

    @shared_credentials.setter
    def shared_credentials(self, shared_credentials):
        """Sets the shared_credentials of this DCMESharingForCollaborationView.


        :param shared_credentials: The shared_credentials of this DCMESharingForCollaborationView.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and shared_credentials is None:
            raise ValueError("Invalid value for `shared_credentials`, must not be `None`")  # noqa: E501

        self._shared_credentials = shared_credentials

    @property
    def users(self):
        """Gets the users of this DCMESharingForCollaborationView.  # noqa: E501


        :return: The users of this DCMESharingForCollaborationView.  # noqa: E501
        :rtype: list[DCMEUserView]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this DCMESharingForCollaborationView.


        :param users: The users of this DCMESharingForCollaborationView.  # noqa: E501
        :type: list[DCMEUserView]
        """
        if self._configuration.client_side_validation and users is None:
            raise ValueError("Invalid value for `users`, must not be `None`")  # noqa: E501

        self._users = users

    @property
    def user_groups(self):
        """Gets the user_groups of this DCMESharingForCollaborationView.  # noqa: E501


        :return: The user_groups of this DCMESharingForCollaborationView.  # noqa: E501
        :rtype: list[DCMEUserGroupView]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this DCMESharingForCollaborationView.


        :param user_groups: The user_groups of this DCMESharingForCollaborationView.  # noqa: E501
        :type: list[DCMEUserGroupView]
        """
        if self._configuration.client_side_validation and user_groups is None:
            raise ValueError("Invalid value for `user_groups`, must not be `None`")  # noqa: E501

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMESharingForCollaborationView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMESharingForCollaborationView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMESharingForCollaborationView):
            return True

        return self.to_dict() != other.to_dict()
